#ifndef AUBO_SDK_RPC_H
#define AUBO_SDK_RPC_H

#include <memory>

#include <aubo/aubo_api.h>
#include <aubo/global_config.h>

namespace arcs {
namespace aubo_sdk {
using namespace arcs::common_interface;

class ARCS_ABI_EXPORT RpcClient : public AuboApi
{
public:
    RpcClient();
    ~RpcClient();

    // 0: LOGLEVEL_FATAL
    // 1: LOGLEVEL_ERROR
    // 2: LOGLEVEL_WARNING
    // 3: LOGLEVEL_INFO
    // 4: LOGLEVEL_DEBUG
    // 5: LOGLEVEL_BACKTRACE
    void setLogHandler(
        std::function<void(int /*level*/, const char * /*filename*/,
                           int /*line*/, const std::string & /*message*/)>
            handler);

    /// 连接到 RPC 服务
    int connect(const std::string &ip, int port);

    /// 断开连接
    int disconnect();

    /// 判断是否连接
    bool hasConnected() const;

    /// 登录
    int login(const std::string &usrname, const std::string &passwd);

    /// 登出
    int logout();

    /// 判断是否登录
    bool hasLogined();

    /// 设置RPC请求超时时间 单位: ms
    int setRequestTimeout(int timeout = 10);
};
using RpcClientPtr = std::shared_ptr<RpcClient>;

} // namespace aubo_sdk
} // namespace arcs
#endif
